#creating MathOperation module
#the module provides addition, subtraction, multiplication, and division functions

#all the functions take two numbers as argument
#creating addition function
#class akpycalc1(object):

def add(num1,num2):
    return num1+num2

    #creating subtraction function
def sub(num1,num2):
    return num1-num2 

    #creating multiplication function
def mult(num1,num2):
    return num1*num2


    #creating division function
def div(num1,num2):
    return num1/num2